@@ -21,7 +21,7 @@ class NestedResolvers(BaseModel):
         edge: str,
         resolver: "Resolver",
         *,
-        merge: bool = True,
+        merge: bool = False,
         ignore_if_subset: bool = False,
         make_first: bool = False,
     ) -> None:
