@@ -82,6 +82,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     _merged: bool = PrivateAttr(False)
     _metadata: dict = PrivateAttr(default=dict)
 
+    _pre_merge_resolver: T.Optional["Resolver"] = PrivateAttr(None)
+
     def __hash__(self):
         return hash(
             str(self._get_nested_query_variables()) + self.to_str() + self._model_name
@@ -224,13 +226,13 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     @property
     def _limit_str(self) -> str:
-        if self._limit is None:
+        if self._limit is None or self._limit == 0:
             return ""
         return f"LIMIT {self._limit}"
 
     @property
     def _offset_str(self) -> str:
-        if self._offset is None:
+        if self._offset is None or self._offset == 0:
             return ""
         return f"OFFSET {self._offset}"
 
@@ -469,16 +471,16 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return query_variables
 
     def all_filters_str(self) -> str:
-        s = ""
-        if self._filter:
-            s += f" {self._filter_str}"
-        if self._order_by:
-            s += f" {self._order_by_str}"
-        if self._offset is not None:
-            s += f" {self._offset_str}"
-        if self._limit is not None:
-            s += f" {self._limit_str}"
-        return s
+        s_lst: list[str] = [
+            self._filter_str,
+            self._order_by_str,
+            self._offset_str,
+            self._limit_str,
+        ]
+        s = " ".join([s for s in s_lst if s])
+        if s:
+            return " " + s
+        return ""
 
     def to_str(self, include_filters: bool = True, ignore_nested: bool = False) -> str:
         """
@@ -529,8 +531,13 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         )
 
     async def query(
-        self, given_client: edgedb.AsyncIOClient = None, only_one: bool = False
+        self,
+        given_client: edgedb.AsyncIOClient = None,
+        only_one: bool = False,
+        merge: bool = True,
     ) -> T.Union[T.List[NodeType], NodeType]:
+        if merge:
+            self.merge()
         query_str = self.full_query_str()
         with safe_span(
             op=f"edgedb.query.{self._model_name}", description=query_str[:200]
@@ -555,8 +562,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         self.clear_filters()
 
     async def get(
-        self, given_client: edgedb.AsyncIOClient = None, **kwargs
+        self, *, given_client: edgedb.AsyncIOClient = None, merge: bool = True, **kwargs
     ) -> T.Optional[NodeType]:
+        if merge:
+            self.merge()
         """Caveat is this must be a string value or an UUID"""
         kwargs = {k: v for k, v in kwargs.items() if v is not None}
         if len(kwargs) != 1:
@@ -588,8 +597,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         with safe_span(op=f"parse.{self._model_name}"):
             return self.parse_nested_obj(raw_d)
 
-    async def gerror(self, **kwargs) -> NodeType:
-        model = await self.get(**kwargs)
+    async def gerror(
+        self, *, given_client: edgedb.AsyncIOClient = None, merge: bool = True, **kwargs
+    ) -> NodeType:
+        model = await self.get(merge=merge, **kwargs)
         if not model:
             raise ResolverException(f"No {self._model_name} in db with fields {kwargs}")
         return model
@@ -629,3 +640,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         node._used_resolver = self.copy(deep=True)
         node._original_dict = raw_d.copy()
         return node
+
+    def merge(self) -> None:
+        from .resolver_helpers import merge_nested_resolver
+
+        pre_merge_resolver = self.copy(deep=True)
+        self._pre_merge_resolver = pre_merge_resolver
+        self._nested_resolvers = merge_nested_resolver(self.nested_resolvers)
